ChamberFirestore class

Constructors

ChamberFirestore()

Properties

chamberReference → CollectionReference<Map<String, dynamic>>
final
hashCode int
The hash code for this object.
no setterinherited
profileReference → Query<Map<String, dynamic>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addPreset(String chamberId, ChamberPreset preset) Future<bool>
override
delete(dynamic chamberId) Future<bool>
override
deletePreset(String chamberId, ChamberPreset preset) Future<bool>
override
fetchAll({bool onlyPublic = false, bool excludeMyFavorites = true, int minItems = 0, int maxLength = 100, String ownerId = '', String excludeFromProfileId = '', OwnerType ownerType = OwnerType.profile}) Future<Map<String, Chamber>>
override
insert(Chamber chamber) Future<String>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retrieve(String chamberId) Future<Chamber>
override
toString() String
A string representation of this object.
inherited
update(Chamber chamber) Future<bool>
override
updatePreset(String chamberId, ChamberPreset preset) Future<bool>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited