currentFootprint property
The current aggregated footprint, or null if none loaded.
Implementation
@override
HarmonicFootprint? get currentFootprint => footprint.value;
The current aggregated footprint, or null if none loaded.
@override
HarmonicFootprint? get currentFootprint => footprint.value;