BinauralConfig class

Personalized binaural beat configuration derived from the Huella Armónica.

Constructors

BinauralConfig({required double carrierHz, required double beatHz, required String targetState})
const

Properties

beatHz double
final
carrierHz double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetState String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited