VocalRange enum

Voice classification based on fundamental frequency range.

Inheritance
Available extensions

Values

bass → const VocalRange
const VocalRange(80, 330, 'Bajo')
baritone → const VocalRange
const VocalRange(100, 400, 'Baritono')
tenor → const VocalRange
const VocalRange(130, 520, 'Tenor')
alto → const VocalRange
const VocalRange(175, 700, 'Alto/Contralto')
mezzoSoprano → const VocalRange
const VocalRange(220, 880, 'Mezzosoprano')
soprano → const VocalRange
const VocalRange(260, 1050, 'Soprano')

Properties

displayName String
Human-readable display name.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
maxHz double
Upper bound of this vocal range in Hz.
final
minHz double
Lower bound of this vocal range in Hz.
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

classify(double fundamentalHz) VocalRange
Classify a fundamental frequency into the best matching vocal range.

Constants

values → const List<VocalRange>
A constant List of the values in this enum, in order of their declaration.