InciensoVisual enum

Visual experience paired with an Incienso.

Inheritance
Available extensions

Values

photonicPulse → const InciensoVisual

Default: screen pulses at beat frequency (photic driving).

flocking → const InciensoVisual

Emergent boid swarm.

breathing → const InciensoVisual

Synchronized breathing circles.

fractals → const InciensoVisual

Infinite Mandelbrot zoom.

neomatics → const InciensoVisual

Chladni plate resonance patterns.

neuroMandala → const InciensoVisual

Generative sacred geometry.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<InciensoVisual>
A constant List of the values in this enum, in order of their declaration.