SourceEffectiveness enum

How effective a given output source is for an Incienso.

Inheritance
Available extensions

Values

optimal → const SourceEffectiveness

Best possible results with this source.

effective → const SourceEffectiveness

Good results — recommended alternative.

partial → const SourceEffectiveness

Works but with reduced effectiveness.

notRecommended → const SourceEffectiveness

Won't achieve the intended therapeutic effect.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SourceEffectiveness>
A constant List of the values in this enum, in order of their declaration.