Boid class

Representa una partícula/pájaro en el sistema de flocking con profundidad 3D

Constructors

Boid({required double x, required double y, double z = 0.5, required double vx, required double vy, double vz = 0, double size = 3.0, Color color = Colors.white, double energy = 1.0})

Properties

color Color
getter/setter pair
depthOpacity double
Opacidad considerando profundidad
no setter
energy double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
position Offset
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
getter/setter pair
velocity Offset
no setter
visualSize double
Tamaño visual considerando profundidad (más lejos = más pequeño)
no setter
vx double
getter/setter pair
vy double
getter/setter pair
vz double
getter/setter pair
x double
getter/setter pair
y double
getter/setter pair
z double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited