FractalPalette class

Color palette preset for each fractal/neuro-state.

Constructors

FractalPalette({required Color color1, required Color color2, required Color color3})
const

Properties

color1 Color
final
color2 Color
final
color3 Color
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited