NeomFrequencyPainterEngine class
- Inheritance
-
- Object
- ChangeNotifier
- NeomFrequencyPainterEngine
Constructors
Properties
- binauralPhase → double
-
no setter
- breathPulse → double
-
no setter
- eegBand → EEGband
-
no setter
- eegColor → Color
-
no setter
- glowIntensity → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hemisphericCoherence → double
-
no setter
- horizontalDrift → double
-
no setter
- lissajousX → double
-
no setter
- lissajousY → double
-
no setter
- phaseL → double
-
no setter
- phaseR → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
samples
→ List<
double> -
no setter
- smoothAmp ↔ double
-
getter/setter pair
- smoothBreath ↔ double
-
getter/setter pair
- smoothNeuro ↔ double
-
getter/setter pair
- visualAmplitudeBase ↔ double
-
getter/setter pair
- visualAmplitudeMax ↔ double
-
getter/setter pair
- visualPhase → double
-
-------- SALIDAS PARA EL PAINTER --------
no setter
- waveHeight → double
-
no setter
- waveStretch → double
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
notifyVisualUpdate(
) → void - Public method to notify listeners from outside the class
-
pushSample(
double value) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setSmoothingProfile(
{required double amplitude, required double breath, required double neuro}) → void -
tickBinaural(
double beatHz, double dt) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateFromAudio(
{required double phase, required double amplitude, required double pan, required double breath, required double modulation, required double neuro, required double frequency}) → void -
updatePhases(
{required double phaseL, required double phaseR}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- bufferSize → const int