notifyVisualUpdate method
void
notifyVisualUpdate()
Public method to notify listeners from outside the class
Implementation
void notifyVisualUpdate() {
notifyListeners();
}
Public method to notify listeners from outside the class
void notifyVisualUpdate() {
notifyListeners();
}