NeomModulatorEngine class

Constructors

NeomModulatorEngine()

Properties

depth double
getter/setter pair
enabled bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
intensity double
getter/setter pair
modFrequency double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type NeomModulationType
getter/setter pair

Methods

apply({required double carrierFreq, required int sampleRate}) double
applyAmplitude(double baseAmp) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited