NeomNeuroStateEngine class

Constructors

NeomNeuroStateEngine()

Properties

hashCode int
The hash code for this object.
no setterinherited
intensity double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyState({required NeomNeuroState state, required NeomBreathEngine breath, required NeomModulatorEngine modulator, required void setIsochronic(bool), required void setIsoFreq(double), required void setSpatialMode(NeomSpatialMode), required void setSpatialIntensity(double)}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited