ChamberController class

Inheritance

Constructors

ChamberController()

Properties

addedChambers → RxList<NeomChamber>
final
baseFreqController TextEditingController
getter/setter pair
binauralBeatController TextEditingController
getter/setter pair
binauralPreview → RxString
final
chamberRepository → ChamberRepository
final
chambers → RxMap<String, NeomChamber>
final
collective ↔ Collective?
getter/setter pair
currentChamber ↔ NeomChamber
getter/setter pair
errorMsg → RxString
final
hashCode int
The hash code for this object.
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isBinauralUpper → RxBool
final
isButtonDisabled → RxBool
final
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isDisposed bool
no setterinherited
isLoading → RxBool
final
isPublicNewChamber → RxBool
final
itemName ↔ RxString
getter/setter pair
itemNumber ↔ RxInt
getter/setter pair
listenersLength int
no setterinherited
newChamberDescController TextEditingController
getter/setter pair
newChamberNameController TextEditingController
getter/setter pair
ownerId String
getter/setter pair
ownerName String
getter/setter pair
ownerType ↔ OwnerType
getter/setter pair
profile ↔ AppProfile
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userServiceImpl → UserService
final

Methods

addListener(SintStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, SintStateUpdate listener) → Disposer
inherited
clear() → void
clearNewChamber() → void
override
containsListener(SintStateUpdate listener) bool
inherited
createChamber() Future<void>
override
debounce<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(milliseconds: 400)}) → void
Calls callback after rx stops changing for duration. Useful for search-as-you-type, form validation, etc.
inherited
deleteChamber(NeomChamber chamber) Future<void>
override
dispose() → void
inherited
ever<T>(RxInterface<T> rx, void callback(T)) → void
Calls callback every time rx changes. Auto-cancels on controller disposal.
inherited
gotoChamberPresets(NeomChamber chamber) Future<void>
override
interval<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(seconds: 1)}) → void
Calls callback at most once per duration, ignoring intermediate changes. Useful for rate-limiting UI updates.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
once<T>(RxInterface<T> rx, void callback(T)) → void
Calls callback only the first time rx changes, then cancels.
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
override
onDelete() → void
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
override
onStart() → void
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclasses. This method should be internal and is required to define the lifetime cycle of the subclass.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
reportAdd(VoidCallback disposer) → void
inherited
reportRead() → void
inherited
setPrivacyOption() Future<void>
override
toggleBinauralDirection(bool? value) → void
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Notifies listeners to update the UI.
inherited
updateChamber(String itemlistId, NeomChamber itemlist) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited