micWaveform property
Real-time microphone waveform bars for visualization during voice detection. Values are normalized 0.0–1.0 amplitudes, max 200 bars.
Implementation
final RxList<double> micWaveform = <double>[].obs;
Real-time microphone waveform bars for visualization during voice detection. Values are normalized 0.0–1.0 amplitudes, max 200 bars.
final RxList<double> micWaveform = <double>[].obs;