CircuitWaveOverlay class
Wraps a widget tree and paints a circuit wave around registered children.
Children register themselves by wrapping with CircuitNode which uses a GlobalKey to report its bounds after layout.
Usage:
CircuitWaveOverlay(
engine: painterEngine,
isActive: controller.isPlaying.value,
child: Column(
children: [
CircuitNode(child: _buildOscilloscope()),
CircuitNode(child: _buildFreqDisplay()),
CircuitNode(child: _buildSliders()),
],
),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CircuitWaveOverlay
Constructors
- CircuitWaveOverlay({Key? key, required NeomFrequencyPainterEngine engine, required bool isActive, Color? primaryColor, Color? secondaryColor, required Widget child})
-
const
Properties
- child → Widget
-
final
- engine → NeomFrequencyPainterEngine
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- primaryColor → Color?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryColor → Color?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CircuitWaveOverlay> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → CircuitWaveOverlayState? - Access the overlay state to register nodes.