MeditationAttentionAnalyzer class

Analyzes mic waveform to determine meditation attention state.

Constructors

MeditationAttentionAnalyzer({double alertThreshold = 0.6})

Properties

focusPercentage double
Get focus percentage (0-100) over the analyzed window.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pushSample(double amplitude) MeditationAttentionState
Push a new amplitude sample and return the current attention state.
reset() → void
Reset for new session.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited