GeneratorTranslationConstants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- activateChamber → const String
- binauralBeat → const String
- breathBox → const String
- breathFourSevenEight → const String
- breathFree → const String
- breathing → const String
- breathOff → const String
- chamberCreated → const String
- chamberPrefs → const String
- chamberPresetAdded → const String
- coherenceDisclaimer → const String
- coherenceMeter → const String
- createPresetList → const String
- detecting → const String
- detectMyVoice → const String
- experiences → const String
- experiencesSubtitle → const String
- findsYourVoiceFrequency → const String
- fractalVisualization → const String
- frequency → const String
- goToExperiences → const String
- helpBreathing → const String
- helpCoherence → const String
- helpIncienso → const String
- helpIsochronic → const String
- helpLissajous → const String
- helpModulation → const String
- helpNeuroState → const String
- helpOscilloscope → const String
- helpSpatiality → const String
- hemisfericCoherence → const String
- isochronicDuty → const String
- isochronicPulse → const String
- lissajous → const String
- modAm → const String
- modFm → const String
- modNone → const String
- modPhase → const String
- modPm → const String
- modulation → const String
- neomChamber → const String
- neuroBreathing → const String
- neuroFlocking → const String
- neuroHarmonicOscilloscope → const String
- neuroharmony → const String
- neuroVR360 → const String
- neuroVR360Stereo → const String
- octave → const String
- octaveBase → const String
- presetAddedMsg → const String
- presetAddError → const String
- presetRemovedMsg → const String
- presetRemoveError → const String
- removePreset → const String
- reviewEmotionDeep → const String
- reviewEmotionEnergized → const String
- reviewEmotionPeaceful → const String
- reviewEmotionRelaxed → const String
- reviewEmotionTransformed → const String
- reviewIntensityGentle → const String
- reviewIntensityIntense → const String
- reviewIntensityLevel → const String
- reviewIntensityModerate → const String
- reviewNoteHint → const String
- reviewOptional → const String
- reviewOverallExperience → const String
- reviewRecommend → const String
- reviewSave → const String
- reviewSkip → const String
- reviewTagAnxiety → const String
- reviewTagCreativity → const String
- reviewTagFocus → const String
- reviewTagMeditate → const String
- reviewTagPain → const String
- reviewTags → const String
- reviewTagSleep → const String
- reviewTagStudy → const String
- reviewTagWorkout → const String
- reviewTierExplorer → const String
- reviewTierMaster → const String
- reviewTierPractitioner → const String
- savePreset → const String
- sessionTime → const String
- spatialCentered → const String
- spatialCrossfade → const String
- spatialHardPan → const String
- spatiality → const String
- spatialOrbit → const String
- spatialSoftPan → const String
- stateCalm → const String
- stateCreativity → const String
- stateFocus → const String
- stateIntegration → const String
- stateNeutral → const String
- states → const String
- stateSleep → const String
- statesSubtitle → const String
- stopChamber → const String
- surroundSound → const String
- updatePreset → const String
- visualMeditative → const String
- visualScientific → const String
- waveLength → const String
- xAxis → const String
- yAxis → const String
- zAxis → const String