NeomBreathEngine class
Constructors
Properties
- breathsPerMinute ↔ double
-
Respiraciones por minuto
getter/setter pair
- currentValue ↔ double
-
getter/setter pair
- depth ↔ double
-
Intensidad de influencia (0–1)
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- intensity ↔ double
-
getter/setter pair
- mode ↔ NeomBreathMode
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
{required double baseAmplitude, required int sampleRate}) → double -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited