FractalConfig class
Configuration for a fractal visualization tied to a NeomNeuroState.
Constructors
- FractalConfig({required NeomFractalType type, required String shaderAsset, double defaultCenterX = -0.5, double defaultCenterY = 0.0, double defaultZoom = 0.5, double maxIterations = 100, double zoomDriftSpeed = 0.0, double colorCycleSpeed = 1.0, required FractalPalette palette, double juliaCx = -0.7, double juliaCy = 0.27015, double power = 3.0})
-
const
Properties
- colorCycleSpeed → double
-
final
- defaultCenterX → double
-
final
- defaultCenterY → double
-
final
- defaultZoom → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- juliaCx → double
-
final
- juliaCy → double
-
final
- maxIterations → double
-
final
- palette → FractalPalette
-
final
- platformIterations → double
-
Returns iteration count scaled for the current platform.
Mobile/web GPUs need fewer iterations to maintain 60fps.
no setter
- power → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shaderAsset → String
-
final
- type → NeomFractalType
-
final
- zoomDriftSpeed → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited