onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() {
super.onInit();
// Receive painter engine from navigation arguments
final args = Sint.arguments;
if (args is List && args.isNotEmpty && args.first is NeomFrequencyPainterEngine) {
_painterEngine = args.first;
} else if (args is NeomFrequencyPainterEngine) {
_painterEngine = args;
}
_ticker = Ticker(_onTick);
_loadAndStart();
}