ui/miniplayer/mini_neom_player library
Classes
- MiniNeomPlayer
- A compact bar that shows when the Neom Chamber (frequency generator) is playing. Sits at the same level as the mini audio player so the user can navigate the app while still hearing the frequency.